@@ -1,13 +1,15 @@
 #!/usr/bin/env python
-# (c) Copyright IBM Corp. 2010, 2017. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2024. All Rights Reserved.
 
-import pkg_resources
 try:
-    __version__ = pkg_resources.get_distribution(__name__).version
-except pkg_resources.DistributionNotFound:
+    from importlib.metadata import distribution, PackageNotFoundError
+except ImportError:
+    from importlib_metadata import distribution, PackageNotFoundError
+try:
+    __version__ = distribution(__name__).version
+except PackageNotFoundError:
     __version__ = None
 
-from .resilient_rest_mock import ResilientMock
 from .co3 import SimpleClient, \
     SimpleHTTPException, \
     PatchConflictException, \
@@ -20,6 +22,7 @@ from .helpers import is_env_proxies_set, get_and_parse_proxy_env_var
 from .co3base import ensure_unicode, \
     get_proxy_dict, \
     BasicHTTPException, \
+    RetryHTTPException, \
     NoChange
 from .co3argparse import parse_parameters, ArgumentParser
 from .co3sslutil import match_hostname
